#
# spec file for package python-pygame
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# There are font issues in the test environment
%bcond_with test

%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-pygame
Version:        1.9.3
Release:        lp151.2.5
Source0:        https://files.pythonhosted.org/packages/source/P/Pygame/pygame-%{version}.tar.gz
Summary:        A Python Module for Interfacing with the SDL Multimedia Library
License:        LGPL-2.1+
Group:          Development/Libraries/Python
Url:            http://www.pygame.org/
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module setuptools}
BuildRequires:  SDL_image-devel
BuildRequires:  SDL_mixer-devel
BuildRequires:  SDL_ttf-devel
BuildRequires:  fdupes
BuildRequires:  fontconfig
BuildRequires:  freetype2-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libpng-devel
BuildRequires:  libv4l-devel >= 0.8.4
BuildRequires:  portmidi-devel
BuildRequires:  python-rpm-macros
BuildRequires:  xorg-x11
Requires:       fontconfig
Requires:       python-numpy
%ifpython2
Provides:       pygame = %{version}
Obsoletes:      pygame < %{version}
%endif

%python_subpackages

%description
Pygame is a Python wrapper module for the SDL multimedia library. It
contains Python functions and classes that allow you to use SDL's
support for playing CD-ROMs, audio and video output, and keyboard,
mouse and joystick input. Pygame also includes support for the
Numerical Python extension. Pygame is the successor to the pySDL
wrapper project, written by Mark Baker.

%package devel
Summary:        Pygame development package
Group:          Development/Libraries/Python
Requires:       python-pygame = %{version}

%description devel
This package contains the header files for developers of Pygame.

%package -n %{name}-doc
Summary:        Pygame documentation and example programs
Group:          Documentation/Other
Provides:       pygame-doc = %{version}
Obsoletes:      pygame-doc < %{version}
Provides:       %{python_module pygame-doc = %{version}}

%description -n %{name}-doc
This package contains documentation and example programs for Pygame.

%prep
%setup -q -n pygame-%{version}
sed -i 's/\r$//' docs/reST/ref/code_examples/draw_module_example.py
sed -i 's/\r$//' docs/reST/ref/code_examples/joystick_calls.py
# Fix wrong-script-interpreter
find examples -name '*.py' -exec sed -i "s|^#!/usr/bin/env python$|#!%{__python3}|" {} \;
find examples -name '*.py' -exec sed -i "s|^#! /usr/bin/env python$|#!%{__python3}|" {} \;
chmod a+x examples/*.py
%fdupes docs
%fdupes examples

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
%python_build

%install
%python_install
%{python_expand pushd %{buildroot}%{$python_sitearch}
sed -i "s|^#!/usr/bin/env python$|#!%{__python3}|" pygame/tests/test_utils/png.py
chmod a+x pygame/tests/test_utils/png.py
chmod a+x pygame/examples/macosx/aliens_app_example/aliens.py
chmod a+x pygame/examples/*.py
chmod a-x pygame/examples/__init__.py
chmod a-x pygame/examples/prevent_display_stretching.py
chmod a-x pygame/examples/freetype_misc.py
$python -m compileall -d %{$python_sitearch} pygame/tests/test_utils/
$python -O -m compileall -d %{$python_sitearch} pygame/tests/test_utils/
%fdupes .
popd
}

%if %{with test}
%check
export SDL_VIDEODRIVER=dummy
export SDL_AUDIODRIVER=disk
%{python_expand export PYTHONPATH=%{buildroot}%{$python_sitearch}
$python -m pygame.tests.__main__ --exclude opengl --time_out 300
}
%endif

%files %{python_files}
%defattr(-,root,root)
%doc LGPL WHATSNEW readme.html readme.rst
%{python_sitearch}/pygame/
%{python_sitearch}/pygame-%{version}-py*.egg-info

%files %{python_files devel}
%defattr(-,root,root)
%doc LGPL
%{python_sysconfig_var INCLUDEPY}/pygame/

%files -n %{name}-doc
%defattr(-,root,root)
%doc LGPL
%doc docs/
%doc examples/

%changelog
* Thu Aug 17 2017 jengelh@inai.de
- Fix RPM group.
* Tue Aug  8 2017 toddrme2178@gmail.com
- Update to version 1.9.3
  * This is a bugfix release which fixes a couple of key issues
    which came up with 1.9.2
- Update to version 1.9.2
- Implement single-spec version
- Fix source URL
- Fix shebangs
- Remove pygame-v4l-2.6.38.patch
  No longer needed
* Sun Oct 12 2014 mailaender@opensuse.org
- fixed rpmlint error devel-file-in-non-devel-package
- patch1 could need a tag
- fixed rpmlint warning self-obsoletion pygame-doc
- ignore missing executable flags in the -docs package
- added missing build requires for portmidi
- fixed rpmlint warning files-duplicate with fdupes
- added rpmlintrc to whitelist the warnings about sample code
- avoid redundancy in the %%description
* Thu Jul  7 2011 idonmez@novell.com
- Add pygame-v4l-2.6.38.patch: use new v4l interface
* Tue Jun  8 2010 prusnak@opensuse.org
- updated to 1.9.1
  * add missing readme.html
  * bugfixes
* Wed Aug  5 2009 matejcik@suse.cz
- update to 1.9.0
  * many bugfixes
  * full python-post-2.5 compatibility, py3k compatibility
- patched setup to workaround broken source tarball (missing readme.html)
- removed py2.5 compatibility patch
* Mon May  4 2009 ro@suse.de
- buildrequires: replace python-numeric by python-numpy
  for >= 11.2
* Fri Mar 20 2009 matejcik@suse.cz
- (re)added libpng-devel and libjpeg-devel for image format support
* Fri Sep 12 2008 matejcik@suse.cz
- update to 1.8.1
  * lots of changes and fixes - see WHATSNEW for details
* Sun Jun  1 2008 crrodriguez@suse.de
- needs fno-strict-aliasing
* Thu Apr  3 2008 prusnak@suse.cz
- updated to 1.8.0
  * lots of changes and fixes - see WHATSNEW for details
- rewrite pep353.diff
* Tue Aug 21 2007 meissner@suse.de
- buildrequire SDL_ttf -> SDL_ttf-devel
* Tue Nov 21 2006 prusnak@suse.cz
- changes according to PEP353 (pep353.diff)
* Tue Feb 28 2006 jmatejek@suse.cz
- updated to reflect python changes due to #149809
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Oct  6 2005 matejcik@suse.cz
- update to 1.7.1release
- removed readme.html, which is no longer provided
* Wed Feb  2 2005 ro@suse.de
- fix build
* Tue Sep 21 2004 mcihar@suse.cz
- update to 1.6.2, this (among others) fixes brokeness on x86_64 - bug #45731
* Fri Jan 30 2004 mcihar@suse.cz
- fixed documentation installation
* Fri Oct 24 2003 mcihar@suse.cz
- update to 1.6 (This new release mainly contains stability and internal
  fixes, small fixes for line and circle primitives, many fixes for locating
  system TrueType fonts, an updated Mac OS X environment, and bigger integer
  storage for Rect objects.)
- patch was included in upstream
- no root for build
* Thu Oct  2 2003 mcihar@suse.cz
- fixed mode related functions that failed on AMD64, thanks to gpayer@suse.de (bug #31709)
* Mon Jun 16 2003 mcihar@suse.cz
- use record-rpm
- updated to 1.5.6
* Mon May 12 2003 mcihar@suse.cz
- use versioned dependency on python
* Wed Jan  8 2003 mcihar@suse.cz
- added obsoletes and provides for rename
- moved doc into %%{_defaultdocdir}/python-pygame
- some doc is in base package with info where to find more
* Mon Jan  6 2003 mcihar@suse.cz
- update to 1.5.5
  * improved Unicode support
  * fixed some bugs
- renamed to python-pygame
* Mon Aug 12 2002 ro@suse.de
- update to 1.5 to get rid of conflict with pause() from unistd
* Mon Feb 18 2002 vinil@suse.cz
- pygame now requires python
* Mon Feb  4 2002 nadvornik@suse.cz
- update to 1.4
* Tue Jan 29 2002 nadvornik@suse.cz
- new package, version 1.3
